driver

package
v1.3.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 21, 2026 License: Apache-2.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

const (
	CSIDriverName = "k8s.csi.datadoghq.com"
)

Variables

This section is empty.

Functions

This section is empty.

Types

type DatadogCSIDriver

type DatadogCSIDriver struct {
	csi.UnimplementedNodeServer
	csi.UnimplementedIdentityServer
	// contains filtered or unexported fields
}

DatadogCSIDriver is datadog CSI driver implementing CSI Node and Identity Server

func NewDatadogCSIDriver

func NewDatadogCSIDriver(name, apmHostSocketPath, dsdHostSocketPath, storageBasePath, version string, apmEnabled bool, allowedRegistries []string) (*DatadogCSIDriver, error)

NewDatadogCSIDriver builds and returns a new Datadog CSI driver

func (*DatadogCSIDriver) GetPluginCapabilities

func (*DatadogCSIDriver) GetPluginInfo

func (*DatadogCSIDriver) NodeGetInfo

func (*DatadogCSIDriver) NodePublishVolume

func (*DatadogCSIDriver) NodeUnpublishVolume

func (*DatadogCSIDriver) Probe

func (*DatadogCSIDriver) Stop added in v1.2.0

func (driver *DatadogCSIDriver) Stop() error

Stop ensures all dependencies are stopped correctly.

func (*DatadogCSIDriver) Version

func (driver *DatadogCSIDriver) Version() string

Version returns the CSI driver version

Directories

Path Synopsis
Package publishers contains the logic for publishing Datadog CSI volumes depending on the volume type.
Package publishers contains the logic for publishing Datadog CSI volumes depending on the volume type.

Jump to