Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EnsureSocketAvailability ¶
EnsureSocketAvailability extracts unix address from a unix endpoint and ensures it is available, deleting the socket if it already exists. If existing socket can't be deleted, or the passed endpoint is not a unix endpoint, an error is returned.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.